@@ -1,7 +1,9 @@
 #
-# Copyright (c) Spyder Project Contributors)
-# Licensed under the terms of the MIT License)
-# (see spyder/__init__.py for details)
+# Copyright (c) 2009- Spyder Kernels Contributors
+#
+# Licensed under the terms of the MIT License
+# (see spyder_kernels/__init__.py for details)
+# -----------------------------------------------------------------------------
 #
 # IMPORTANT NOTE: Don't add a coding line here! It's not necessary for
 # site files
@@ -228,17 +230,12 @@ class IPyTesProgram(TestProgram):
         TestProgram.__init__(self, *args, **kwargs)
 unittest.main = IPyTesProgram
 
-# Patch ipykernel to avoid errors when setting the Qt5 Matplotlib
-# backemd
-# Fixes Issue 6091
-import ipykernel
-import IPython
-if LooseVersion(ipykernel.__version__) <= LooseVersion('4.7.0'):
-    if ((PY2 and LooseVersion(IPython.__version__) >= LooseVersion('5.5.0')) or
-        (not PY2 and LooseVersion(IPython.__version__) >= LooseVersion('6.2.0'))
-       ):
-        from ipykernel import eventloops
-        eventloops.loop_map['qt'] = eventloops.loop_map['qt5']
+# Ignore some IPython/ipykernel warnings
+try:
+    warnings.filterwarnings(action='ignore', category=DeprecationWarning,
+                            module='ipykernel.ipkernel')
+except:
+    pass
 
 
 #==============================================================================
@@ -282,6 +279,35 @@ except:
     pass
 
 
+# =============================================================================
+# Multiprocessing adjustments
+# =============================================================================
+# This patch is only needed on Windows and Python 3
+if os.name == 'nt' and not PY2:
+    # This could fail with changes in Python itself, so we protect it
+    # with a try/except
+    try:
+        import multiprocessing.spawn
+        _old_preparation_data = multiprocessing.spawn.get_preparation_data
+
+        def _patched_preparation_data(name):
+            """
+            Patched get_preparation_data to work when all variables are
+            removed before execution.
+            """
+            try:
+                return _old_preparation_data(name)
+            except AttributeError:
+                main_module = sys.modules['__main__']
+                # Any string for __spec__ does the job
+                main_module.__spec__ = ''
+                return _old_preparation_data(name)
+
+        multiprocessing.spawn.get_preparation_data = _patched_preparation_data
+    except Exception:
+        pass
+
+
 #==============================================================================
 # Pdb adjustments
 #==============================================================================
